/*-----------------------------------------------------------------------*/
/*                                   TIGA                                */
/*         Copyright (C) 1988-1991  Texas Instruments Incorporated.      */
/*                           All Rights Reserved                         */
/*-----------------------------------------------------------------------*/
/*  TIGA - Header file                                                   */
/*-----------------------------------------------------------------------*/
/*                                                                       */
/*  file            gsptiga.h (GSP-C equivalent of tiga.h)               */
/*                                                                       */
/*  description     This file contains references to TIGA core functions */
/*                  It is needed for the gsp side of an application,     */
/*                  written in GSP-C, which invokes TIGA core functions. */
/*                                                                       */
/*-----------------------------------------------------------------------*/
#include <gsptypes.h>

/*----------------------------------------------------------------------*/
/*  Reference Core Primitives                                           */
/*----------------------------------------------------------------------*/
extern          void   clear_frame_buffer(unsigned long);
extern          void   clear_page(unsigned long);
extern          void   clear_screen(unsigned long);
extern          void   cop2gsp(short, PTR, PTR, long);
extern          short  cpw(short, short);
extern          PTR    cvxyl(short, short);
extern unsigned long   field_extract(PTR, unsigned short);
extern          void   field_insert(PTR, short, unsigned long);
extern          void   get_colors(unsigned long *, unsigned long *);
extern          void   get_config(CONFIG *);
extern          short  get_curs_state(void);
extern          void   get_curs_xy(short *, short *);
extern          short  get_fontinfo(short, FONTINFO *);
extern          void   get_isr_priorities(short, short *);
extern unsigned long   get_nearest_color(unsigned char, unsigned char, unsigned char, unsigned char);
extern          void   get_offscreen_memory(short, OFFSCREEN_AREA *);
extern          void   get_palet(short, PALET *);
extern          short  get_palet_access(void);
extern          short  get_palet_entry(long, unsigned char *, unsigned char *, unsigned char *, unsigned char *);
extern unsigned long   get_pmask(void);
extern unsigned short  get_ppop(void);
extern          void   get_text_xy(short *, short *);
extern          short  get_transp(void);
extern          PTR    get_vector(short);   
extern          short  get_windowing(void);
extern          short  get_wksp(PTR *, unsigned long *);
extern          short  gm_idlefunction(short, short);
extern          void   gsp2cop(short, PTR, PTR, long);
extern          void   gsp2gsp(PTR, PTR, unsigned long);
extern unsigned short  gsph_alloc(unsigned long);
extern unsigned short  gsph_calloc(unsigned long, unsigned long);
extern          void   gsph_compact(short);
extern          PTR    gsph_deref(unsigned short);
extern unsigned short  gsph_falloc(unsigned long, PTR, unsigned char);
extern unsigned short  gsph_fcalloc(unsigned long, unsigned long, PTR, unsigned char);
extern unsigned short  gsph_findhandle(PTR);
extern          short  gsph_findmem(PTR, unsigned short *, unsigned char *);
extern          void   gsph_free(unsigned short);
extern          void   gsph_init(long);  
extern unsigned long   gsph_maxheap(void);
extern          void   gsph_memtype(unsigned short, unsigned char);
extern unsigned long   gsph_realloc(unsigned short, unsigned long);
extern unsigned long   gsph_totalfree(void);
extern          PTR    gsp_calloc(long, long);
extern          short  gsp_free(PTR);
extern          PTR    gsp_malloc(long);
extern unsigned long   gsp_maxheap(void);
extern          void   gsp_minit(long);  
extern          PTR    gsp_realloc(PTR, unsigned long);
extern          void   init_palet(void);
extern          void   init_text(void);
extern          short  lmo(unsigned long);
extern          short  page_busy(void);
extern          void   page_flip(short, short);
extern unsigned long   peek_breg(short);
extern          void   poke_breg(short, unsigned long);
extern          short  rmo(unsigned long);
extern          void   set_bcolor(unsigned long);
extern          void   set_clip_rect(unsigned short, unsigned short, short, short);
extern          void   set_colors(unsigned long, unsigned long);
extern          void   set_curs_shape(PTR);
extern          void   set_curs_state(short);
extern          void   set_curs_xy(short, short);
extern          void   set_cursattr(unsigned long, unsigned long, unsigned short, unsigned short);
extern          void   set_fcolor(unsigned long);
extern          short  set_interrupt(short, short, short, short);
extern          short  set_module_state(short, short);
extern          void   set_palet(long, long, PALET *);
extern          short  set_palet_access(short);
extern          short  set_palet_entry(long, unsigned char, unsigned char, unsigned char, unsigned char);
extern          void   set_pmask(unsigned long);
extern          void   set_ppop(short);
extern          void   set_text_xy(short, short);
extern          void   set_transp(short);
extern          PTR    set_vector(short, PTR);
extern          void   set_windowing(short);
extern          void   set_wksp(PTR, PTR);
extern          short  sym_flush(short);
extern          short  text_out(short, short, char *);
extern          void   text_outp(char *);
extern          void   transp_off(void);
extern          void   transp_on(void);
extern          void   wait_scan(short);

/*----------------------------------*/
/* Callback Packet Definitions      */
/*----------------------------------*/
#define __WORD(a)           0,2,a
#define __DWORD(a)          0,4,a
#define __BYTE_PTR(a,b)     1,a,b
#define __WORD_PTR(a,b)     1,a*2,b
#define __ALTBYTE_PTR(a,b)  129,a,b
#define __ALTWORD_PTR(a,b)  129,a*2,b
#define __INBYTE_PTR(a,b)   161,a,b
#define __INWORD_PTR(a,b)   161,a*2,b
#define __STRING(a)         65,a

/*----------------------------------*/
/* Colors of the default TIGA palet */
/*----------------------------------*/
#define  BLACK          0
#define  BLUE           1
#define  GREEN          2
#define  CYAN           3
#define  RED            4
#define  MAGENTA        5
#define  BROWN          6
#define  LIGHT_GRAY     7
#define  DARK_GRAY      8
#define  LIGHT_BLUE     9
#define  LIGHT_GREEN    10
#define  LIGHT_CYAN     11
#define  LIGHT_RED      12
#define  LIGHT_MAGENTA  13
#define  YELLOW         14
#define  WHITE          15

/*----------------------------------*/
/* Memory System Equates            */
/*----------------------------------*/
#define TRUE    1
#define FALSE   0
#define BLK_DELETABLE   0x01    /* Block can be deleted */
#define BLK_LOCKED      0x02    /* Block is locked */
#define BLK_FUNCMOVE    0x04    /* Call block function on move */
#define BLK_FUNCDELETE  0x08    /* Call block function on purge */
#define BLK_SECURED     0x10    /* Block is secured memory */
#define BLK_INUSE       0x20    /* Block is allocated */

/*----------------------------------*/
/* Extended primitives module id    */
/* - parameter to sym_flush         */
/*----------------------------------*/
#define GRAPHICS_LIB_ID 0x3C00
